@@ -7,7 +7,17 @@ import math
 import sys
 from datetime import datetime
 from pathlib import Path
-from typing import List, Counter, Dict, Generator, Optional, Union, Tuple, Sequence
+from typing import (
+    List,
+    Counter,
+    Dict,
+    Generator,
+    Optional,
+    Union,
+    Tuple,
+    Sequence,
+    Iterable,
+)
 
 import attr
 import click
@@ -259,24 +269,56 @@ def validate_product(doc: Dict) -> ValidationMessages:
     else:
         seen_names_and_aliases = collections.defaultdict(list)
         for measurement in measurements:
-            name = measurement.get("name")
+            measurement_name = measurement.get("name")
             dtype = measurement.get("dtype")
             nodata = measurement.get("nodata")
             if not numpy_value_fits_dtype(nodata, dtype):
                 yield _error(
                     "unsuitable_nodata",
-                    f"Measurement {name!r} nodata {nodata!r} does not fit a {dtype!r}",
+                    f"Measurement {measurement_name!r} nodata {nodata!r} does not fit a {dtype!r}",
                 )
 
-            for new_field in (name, *measurement.get("aliases", ())):
-                if new_field in seen_names_and_aliases:
-                    seen_in = ", ".join({name, *seen_names_and_aliases[new_field]})
+            # Were any of the names seen in other measurements?
+            these_names = measurement_name, *measurement.get("aliases", ())
+            for new_field_name in these_names:
+                measurements_with_this_name = seen_names_and_aliases[new_field_name]
+                if measurements_with_this_name:
+                    seen_in = " and ".join(repr(s) for s in measurements_with_this_name)
+
+                    # If the same name is used by different measurements, its a hard error.
                     yield _error(
                         "duplicate_measurement_name",
-                        f"Name {new_field!r} is used more than once in a measurement name or alias.",
-                        hint=f"Seen in {seen_in}",
+                        f"Name {new_field_name!r} is used by multiple measurements",
+                        hint=f"It's duplicated in an alias. "
+                        f"Seen in measurement(s) {seen_in}",
                     )
-                seen_names_and_aliases[new_field].append(name)
+
+            # Are any names duplicated within the one measurement? (not an error, but info)
+            for duplicate_name in _find_duplicates(these_names):
+                yield _info(
+                    "duplicate_alias_name",
+                    f"Measurement {measurement_name!r} has a duplicate alias named {duplicate_name!r}",
+                )
+
+            for field in these_names:
+                seen_names_and_aliases[field].append(measurement_name)
+
+
+def _find_duplicates(values: Iterable[str]) -> Generator[str, None, None]:
+    """Return any duplicate values in the given sequence
+
+    >>> list(_find_duplicates(('a', 'b', 'c')))
+    []
+    >>> list(_find_duplicates(('a', 'b', 'b')))
+    ['b']
+    >>> list(_find_duplicates(('a', 'b', 'b', 'a')))
+    ['a', 'b']
+    """
+    previous = None
+    for v in sorted(values):
+        if v == previous:
+            yield v
+        previous = v
 
 
 def numpy_value_fits_dtype(value, dtype):
@@ -324,61 +366,73 @@ def validate_paths(
     paths: List[Path],
     thorough: bool = False,
     expect_extra_measurements: bool = False,
-) -> Generator[Tuple[Path, List[ValidationMessage]], None, None]:
+) -> Generator[Tuple[Path, int, List[ValidationMessage]], None, None]:
     """Validate the list of paths. Product documents can be specified before their datasets."""
     products: Dict[str, Dict] = {}
 
     for path in paths:
-        # Load yaml. If product, add to products.
-        # Otherwise validate.
-        doc = serialise.load_yaml(path)
-        messages = []
-
-        if is_product(doc):
-            messages.extend(validate_product(doc))
-            products[doc["name"]] = doc
-            yield path, messages
-            continue
-
-        # TODO: follow ODC's match rules?
-        product = None
-        product_name = get_path(doc, ("product", "name"), default=None)
-
-        if products:
-            if len(products) == 1:
-                [product] = products.values()
-            elif product_name is not None:
-                product = products.get(product_name)
-
-            if product is None:
-                messages.append(
-                    _warning(
-                        "unknown_product",
-                        "Cannot match dataset to product",
-                        hint=f"Nothing matches {product_name!r}"
-                        if product_name
-                        else "No product name in dataset (TODO: field matching)",
+        with path.open("r") as f:
+            inner_docs = serialise.loads_yaml(f)
+            for i, doc in enumerate(inner_docs):
+                if is_product(doc):
+                    products[doc["name"]] = doc
+                    messages = list(validate_product(doc))
+                else:
+                    messages = validate_eo3_doc(
+                        doc, path, products, thorough, expect_extra_measurements
                     )
-                )
-        else:
+                if messages:
+                    yield path, i, messages
+
+
+def validate_eo3_doc(
+    doc: Dict,
+    location: Union[str, Path],
+    products: Dict[str, Dict],
+    thorough: bool = False,
+    expect_extra_measurements=False,
+) -> List[ValidationMessage]:
+    messages = []
+
+    # TODO: follow ODC's match rules?
+    product = None
+    product_name = get_path(doc, ("product", "name"), default=None)
+
+    if products:
+        if len(products) == 1:
+            [product] = products.values()
+        elif product_name is not None:
+            product = products.get(product_name)
+
+        if product is None:
             messages.append(
-                ValidationMessage(
-                    Level.error if thorough else Level.info,
-                    "no_product",
-                    "No product provided: validating dataset information alone",
+                _warning(
+                    "unknown_product",
+                    "Cannot match dataset to product",
+                    hint=f"Nothing matches {product_name!r}"
+                    if product_name
+                    else "No product name in dataset (TODO: field matching)",
                 )
             )
-
-        messages.extend(
-            validate_dataset(
-                doc,
-                product_definition=product,
-                readable_location=path,
-                thorough=thorough,
-                expect_extra_measurements=expect_extra_measurements,
+    else:
+        messages.append(
+            ValidationMessage(
+                Level.error if thorough else Level.info,
+                "no_product",
+                "No product provided: validating dataset information alone",
             )
         )
-        yield path, messages
+
+    messages.extend(
+        validate_dataset(
+            doc,
+            product_definition=product,
+            readable_location=location,
+            thorough=thorough,
+            expect_extra_measurements=expect_extra_measurements,
+        )
+    )
+    return messages
 
 
 def is_product(doc: Dict) -> bool:
@@ -550,7 +604,7 @@ def run(
         Level.warning: dict(fg="yellow"),
         Level.error: dict(fg="red"),
     }
-    for path, messages in validate_paths(
+    for path, path_index, messages in validate_paths(
         paths, thorough=thorough, expect_extra_measurements=expect_extra_measurements
     ):
         levels = collections.Counter(m.level for m in messages)
@@ -563,7 +617,8 @@ def run(
             messages = [m for m in messages if m.level != Level.info]
 
         if messages or not quiet:
-            secho(f"{bool_style(not is_invalid)} {path.stem}")
+            path_suffix = f" document {path_index+1}" if path_index else ""
+            secho(f"{bool_style(not is_invalid)} {path.stem}{path_suffix}")
 
         if not messages:
             continue
