@@ -7,17 +7,16 @@ import pytest
 from eodatasets3.prepare import sentinel_l1c_prepare
 from tests.common import check_prepare_outputs
 
-path = (
+DATASET_DIR: Path = Path(__file__).parent.parent / (
     "data/sinergise_s2_l1c/S2B_MSIL1C_20201011T000249_N0209_R030_T55HFA_20201011T011446"
 )
 
-DATASET_DIR: Path = Path(__file__).parent.parent / path
-
 
 @pytest.fixture()
 def expected_dataset_document():
     return {
         "$schema": "https://schemas.opendatacube.org/dataset",
+        "id": "f3e0eee1-573c-5035-870e-8d8392df8e33",
         "crs": "epsg:32755",
         "geometry": {
             "coordinates": [
@@ -77,7 +76,7 @@ def expected_dataset_document():
                 ],
             },
         },
-        "label": "sinergise_s2am_level1_1-0-20201011_55HFA_2020-10-11",
+        "label": "sinergise_s2bm_level1_1-0-20201011_55HFA_2020-10-11",
         "lineage": {},
         "measurements": {
             "blue": {"grid": "998", "path": "B02.jp2"},
@@ -103,15 +102,15 @@ def expected_dataset_document():
                 "path": "B09.jp2",
             },
         },
-        "product": {"name": "sinergise_s2am_level1_1"},
+        "product": {"name": "sinergise_s2bm_level1_1"},
         "properties": {
-            "datetime": datetime.datetime(2020, 10, 11, 0, 6, 49, 882000),
+            "datetime": datetime.datetime(2020, 10, 11, 0, 6, 49, 882566),
             "eo:cloud_cover": 24.9912,
             "eo:gsd": 10,
             "eo:instrument": "MSI",
-            "eo:platform": "sentinel-2a",
-            "eo:sun_azimuth": 37.3713908882192,
-            "eo:sun_elevation": 46.3307328858312,
+            "eo:platform": "sentinel-2b",
+            "eo:sun_azimuth": 46.3307328858312,
+            "eo:sun_elevation": 37.3713908882192,
             "odc:dataset_version": "1.0.20201011",
             "odc:file_format": "JPEG2000",
             "odc:processing_datetime": datetime.datetime(
@@ -124,7 +123,7 @@ def expected_dataset_document():
             "sentinel:latitude_band": "H",
             "sentinel:utm_zone": 55,
             "sinergise_product_id": "73e1a409-595d-4fbf-8fe0-01e0ee26bf00",
-            "sinergise_product_name": "S2B_MSIL1C_20201011T000249_N0209_R030_T55HFA_20201011T011446",
+            "sentinel:product_name": "S2B_MSIL1C_20201011T000249_N0209_R030_T55HFA_20201011T011446",
             "sentinel:datastrip_id": "S2B_OPER_MSI_L1C_DS_EPAE_20201011T011446_S20201011T000244_N02.09",
             "sentinel:datatake_start_datetime": datetime.datetime(
                 2020, 10, 11, 1, 14, 46
@@ -132,41 +131,28 @@ def expected_dataset_document():
             "sentinel:sentinel_tile_id": "S2B_OPER_MSI_L1C_TL_EPAE_20201011T011446_A018789_T55HFA_N02.09",
         },
         "accessories": {
-            "metadata:product_info": {"path": "productInfo.json"},
-            "metadata:sinergise_metadata": {"path": "metadata.xml"},
+            "metadata:sinergise_product_info": {"path": "productInfo.json"},
+            "metadata:s2_tile": {"path": "metadata.xml"},
         },
     }
 
 
 def test_sinergise_sentinel_l1(tmp_path, expected_dataset_document):
-
-    # GIVEN:
-    #     A folder of imagery
-    outdir = tmp_path / DATASET_DIR.name
-    indir = DATASET_DIR
-
-    if indir.is_file():
-        shutil.copy(indir, outdir)
-    else:
-        shutil.copytree(indir, outdir)
-
-    # WHEN:
-    #    Run prepare on that folder
+    """
+    Run prepare on our test dataset, and check the out metadata doc matches.
+    """
+    work_dir = tmp_path / DATASET_DIR.name
+    shutil.copytree(DATASET_DIR, work_dir)
 
     output_yaml_path = (
-        outdir
+        work_dir
         / "S2B_MSIL1C_20201011T000249_N0209_R030_T55HFA_20201011T011446.odc-metadata.yaml"
     )
-
-    # THEN
-    #     A metadata file is added to it, with valid properties
-    #     Assert doc is expected doc
     check_prepare_outputs(
         invoke_script=sentinel_l1c_prepare.main,
         run_args=[
-            outdir,
+            work_dir,
         ],
         expected_doc=expected_dataset_document,
         expected_metadata_path=output_yaml_path,
-        ignore_fields=["id"],
     )
